==> manydhcp2.5.2.tar.bz2: manydhcp/etazh/editform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  $title=$titlepage = $TEXT['etazh-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(!isset($button)) $button = $TEXT['btn_save'];
  if(!isset($action)) $action = "edit.php";

  if(strlen($_GET['etazh_id'])>5) {puterror($result2['skin'],$TEXT['error-etazh6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['etazh_id'] = rep($_GET['etazh_id']);

  $old_etazh_id = $_GET['etazh_id'];

  $query10 = "SELECT * FROM `tbl_etazh` WHERE `etazh_id`='".$_GET['etazh_id']."' ";
  $result10 = mysql_query($query10);
  if (!$result10) {puterror($result2['skin'],$TEXT['error-tbl11']); require_once "../utils/bottom_adm.php"; exit();}
      $result_etazh = mysql_fetch_array($result10);
         $etazh = $result_etazh['etazh'];
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center">
<tr><td class="bold_it"><?php echo $TEXT['global-edit']; ?></td><td class="bold_it"><input size=20 maxlength=20 class="input" type=text name=etazh value='<?php echo $etazh; ?>'></td></tr>
<tr><td></td><td>
<input class="button2" type=submit value='<?php echo $button; ?>'>
<input type=hidden name=etazh_id value='<?php echo $old_etazh_id; ?>'>
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.8.2.tar.bz2: manydhcp/etazh/editform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['etazh-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  $button = $TEXT['btn_save'];
  $action = "edit.php";

  if(strlen($_GET['etazh_id'])>5) {puterror($result2['skin'],$TEXT['error-etazh6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['etazh_id'] = rep($_GET['etazh_id']);

  $old_etazh_id = $_GET['etazh_id'];

  $query10 = "SELECT * FROM `tbl_etazh` WHERE `etazh_id`='".$_GET['etazh_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl11']); require_once "../utils/bottom_adm.php"; exit();}
      $result_etazh = mysqli_fetch_array($result10,MYSQLI_ASSOC);
         $etazh = $result_etazh['etazh'];
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center">
<tr><td class="bold_it"><?php echo $TEXT['global-edit']; ?></td><td class="bold_it"><input size=20 maxlength=20 class="input" type=text name=etazh value='<?php echo $etazh; ?>'></td></tr>
<tr><td></td><td>
<input class="button2" type=submit value='<?php echo $button; ?>'>
<input type=hidden name=etazh_id value='<?php echo $old_etazh_id; ?>'>
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>
